"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGitRepoFirstCommitInfo = exports.getGitRepoRootPath = exports.getGitRepoCurrentBranch = exports.getGitRepoRemoteUrl = void 0;
const child_process_1 = require("child_process");
function getGitRepoRemoteUrl(cwd) {
    try {
        const res = child_process_1.execSync(`git remote -v`, {
            cwd: cwd || process.cwd(),
        })
            .toString()
            .split('\n');
        const matchResult = res[0].trim().match(/[^\s]*\s+(.*)\s+\(.*/i);
        return matchResult && matchResult[1] || '';
    }
    catch (e) {
        return '';
    }
}
exports.getGitRepoRemoteUrl = getGitRepoRemoteUrl;
function getGitRepoCurrentBranch(cwd) {
    try {
        const res = child_process_1.execSync(`git symbolic-ref --short -q HEAD`, {
            cwd: cwd || process.cwd(),
        })
            .toString()
            .split('\n');
        return res[0];
    }
    catch (e) {
        return '';
    }
}
exports.getGitRepoCurrentBranch = getGitRepoCurrentBranch;
function getGitRepoRootPath(cwd) {
    try {
        const res = child_process_1.execSync(`git rev-parse --show-toplevel`, {
            cwd: cwd || process.cwd(),
        })
            .toString()
            .split('\n');
        return res[0];
    }
    catch (e) {
        return '';
    }
}
exports.getGitRepoRootPath = getGitRepoRootPath;
function getGitRepoFirstCommitInfo(cwd) {
    try {
        const res = child_process_1.execSync('git log --reverse --pretty="%H!!!%h!!!%aN!!!%aE!!!%ad!!!%B"', {
            cwd: cwd || process.cwd(),
        })
            .toString()
            .split('\n');
        const first = res[0].split('!!!');
        return {
            hash: first[0],
            abbrevHash: first[1],
            authorName: first[2],
            authorEmail: first[3],
            authorDate: first[4],
            subject: first[5],
        };
    }
    catch (e) {
        return undefined;
    }
}
exports.getGitRepoFirstCommitInfo = getGitRepoFirstCommitInfo;
